==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa.md <==
# AmazonSimpleStorageServiceS3OneZoneIa


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')
```



| Illustration | AmazonSimpleStorageServiceS3OneZoneIa | AmazonSimpleStorageServiceS3OneZoneIaCard | AmazonSimpleStorageServiceS3OneZoneIaGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa.png) | ![illustration for AmazonSimpleStorageServiceS3OneZoneIa](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa.Local.png) | ![illustration for AmazonSimpleStorageServiceS3OneZoneIaCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIaCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3OneZoneIaGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIaGroup.Local.png) |




## AmazonSimpleStorageServiceS3OneZoneIa

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIa
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIa('AmazonSimpleStorageServiceS3OneZoneIa', 'Amazon Simple Storage Service S3 One Zone Ia', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIa
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIa('AmazonSimpleStorageServiceS3OneZoneIa', 'Amazon Simple Storage Service S3 One Zone Ia', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3OneZoneIaCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIaCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIaCard('AmazonSimpleStorageServiceS3OneZoneIaCard', 'Amazon Simple Storage Service S3 One Zone Ia Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIaCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIaCard('AmazonSimpleStorageServiceS3OneZoneIaCard', 'Amazon Simple Storage Service S3 One Zone Ia Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3OneZoneIaGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIaGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIaGroup('AmazonSimpleStorageServiceS3OneZoneIaGroup', 'Amazon Simple Storage Service S3 One Zone Ia Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIaGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIaGroup('AmazonSimpleStorageServiceS3OneZoneIaGroup', 'Amazon Simple Storage Service S3 One Zone Ia Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa.md <==
# AmazonSimpleStorageServiceS3OneZoneIa


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')
```



| Illustration | AmazonSimpleStorageServiceS3OneZoneIa | AmazonSimpleStorageServiceS3OneZoneIaCard | AmazonSimpleStorageServiceS3OneZoneIaGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa.png) | ![illustration for AmazonSimpleStorageServiceS3OneZoneIa](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa.Local.png) | ![illustration for AmazonSimpleStorageServiceS3OneZoneIaCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIaCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3OneZoneIaGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIaGroup.Local.png) |




## AmazonSimpleStorageServiceS3OneZoneIa

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIa
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIa('AmazonSimpleStorageServiceS3OneZoneIa', 'Amazon Simple Storage Service S3 One Zone Ia', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIa
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIa('AmazonSimpleStorageServiceS3OneZoneIa', 'Amazon Simple Storage Service S3 One Zone Ia', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3OneZoneIaCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIaCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIaCard('AmazonSimpleStorageServiceS3OneZoneIaCard', 'Amazon Simple Storage Service S3 One Zone Ia Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIaCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIaCard('AmazonSimpleStorageServiceS3OneZoneIaCard', 'Amazon Simple Storage Service S3 One Zone Ia Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3OneZoneIaGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIaGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIaGroup('AmazonSimpleStorageServiceS3OneZoneIaGroup', 'Amazon Simple Storage Service S3 One Zone Ia Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OneZoneIaGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3OneZoneIa')

' renders the element
AmazonSimpleStorageServiceS3OneZoneIaGroup('AmazonSimpleStorageServiceS3OneZoneIaGroup', 'Amazon Simple Storage Service S3 One Zone Ia Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
